@@ -712,6 +712,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
     this.widget.findChild("LabelLinetypeScale").enabled = gotLinetypeScaleProperty;
     w = this.widget.findChild("LinetypeScale");
     w.enabled = gotLinetypeScaleProperty;
+    w.setTextColor(false);
     if (!gotLinetypeScaleProperty) {
         w.text = "";
     }
@@ -1363,16 +1364,19 @@ PropertyEditorImpl.prototype.makeReadOnly = function(control) {
     }
 
     var p = control.palette;
-    if (isNull(control.oriBase)) {
-        control.setProperty("oriBase", control.palette.color(QPalette.Base));
+    if (isNull(control.oriPalette)) {
+        control.setProperty("oriPalette", control.palette);
     }
 
-    if (RSettings.hasDarkGuiBackground()) {
-        p.setColor(QPalette.Base, new QColor("#0a0a0a"));
-    }
-    else {
-        p.setColor(QPalette.Base, new QColor("#eeeeee"));
-    }
+    p.setColor(QPalette.Active, QPalette.Text, control.oriPalette.color(QPalette.Disabled, QPalette.WindowText));
+    p.setColor(QPalette.Inactive, QPalette.Text, control.oriPalette.color(QPalette.Disabled, QPalette.WindowText));
+
+//    if (RSettings.hasDarkGuiBackground()) {
+//        p.setColor(QPalette.Base, new QColor("#0a0a0a"));
+//    }
+//    else {
+//        p.setColor(QPalette.Base, new QColor("#eeeeee"));
+//    }
     control.palette = p;
 
     control.readOnly = true;
@@ -1389,15 +1393,18 @@ PropertyEditorImpl.prototype.makeReadWrite = function(control) {
     }
 
     var p = control.palette;
-    if (isNull(control.oriBase)) {
-        control.setProperty("oriBase", control.palette.color(QPalette.Base));
+    if (isNull(control.oriPalette)) {
+        control.setProperty("oriPalette", control.palette);
     }
-    //if (RSettings.hasDarkGuiBackground()) {
-        p.setColor(QPalette.Base, control.oriBase);
-//    }
-//    else {
-//        p.setColor(QPalette.Base, new QColor("#ffffff"));
-//    }
+
+    p.setColor(QPalette.Active, QPalette.Text, control.oriPalette.color(QPalette.Active, QPalette.WindowText));
+    p.setColor(QPalette.Inactive, QPalette.Text, control.oriPalette.color(QPalette.Inactive, QPalette.WindowText));
+//    //if (RSettings.hasDarkGuiBackground()) {
+//        p.setColor(QPalette.Base, control.oriBase);
+////    }
+////    else {
+////        p.setColor(QPalette.Base, new QColor("#ffffff"));
+////    }
     control.palette = p;
 
     control.readOnly = false;
